#
# spec file for package ghc-constraints
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name constraints
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.12
Release:        bp153.1.20
Summary:        Constraint manipulation
License:        BSD-2-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-semigroups-devel
BuildRequires:  ghc-transformers-compat-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-type-equality-devel
%if %{with tests}
BuildRequires:  ghc-hspec-devel
%endif

%description
GHC 7.4 gave us the ability to talk about 'ConstraintKinds'. They stopped
crashing the compiler in GHC 7.6.

This package provides a vocabulary for working with them.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.markdown README.markdown

%changelog
* Fri Feb  7 2020 psimons@suse.com
- Update constraints to version 0.12.
  0.12 [2020.02.03]
  - ----------------
  * Relax the type signature for `divideTimes`:
    ```diff
  - dividesTimes :: (Divides a b, Divides a c) :- Divides a (b * c)
    +dividesTimes ::  Divides a b               :- Divides a (b * c)
    ```
  * Simplify the type signature of `dividesDef`:
    ```diff
  - dividesDef :: forall a b. Divides a b :- ((a * Div b a) ~ b)
    +dividesDef :: forall a b. Divides a b :- (Mod b a ~ 0)
    ```
    The original type of `diviesDef` can be (partially) recovered by defining
    it in terms of the new `dividesDef`:
    ```hs
    dividesDef' :: forall a b. (1 <= a, Divides a b) :- ((a * Div b a) ~ b)
    dividesDef' = Sub $ case (dividesDef @a @b, euclideanNat @a @b) of
    (Sub Dict, Sub Dict) -> Dict
    ```
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Sep  7 2019 psimons@suse.com
- Update constraints to version 0.11.2.
  0.11.2 [2019.09.06]
  - ------------------
  * Depend on the `type-equality` compatibility library so that `(:~~:)` may be
    used when compiling this library with GHC 8.0. This avoids having to redefine
    `(:~~:)` directly in the internals of `constraints` itself.
* Wed Aug 28 2019 psimons@suse.com
- Update constraints to version 0.11.1.
  0.11.1 [2019.08.27]
  - ------------------
  * Make `Data.Constraint.Deferrable.UnsatisfiedConstraint` a newtype.
* Sat May 11 2019 psimons@suse.com
- Update constraints to version 0.11.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/constraints-0.11/src/CHANGELOG.markdown
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Mon Jul  9 2018 psimons@suse.com
- Add constraints at version 0.10.1.
